A crate to generate typesystem-level UUIDs
By default, all of the macros produce ::typenum::Unsigned
types.
If typenum is located somewhere else, you can append
| path::to::typenum to the macro argument, and it will use
that prefix instead:
use ::typenum as some_other_name;
type ID = uuid_new_v4!( | some_other_name );This feature is most useful when exporting macros from a crate
that relies on typenum: the UUIDs can be made to use your
crate’s re-export of typenum, in case your users have an
incompatible version.
Macros
- uuid
- Construct a typenum UUID
- uuid_
new_ v4 - Construct a new random UUID
- uuid_
new_ v4_ literal